Struct ffi_gen::FfiGen[][src]

pub struct FfiGen { /* fields omitted */ }
Main entry point to ffi-gen.

Implementations

Takes a path to an ffi-gen interface description file and constructs a new FfiGen instance.

Generates the rust api.

Patches the ffi functions in a wasm blob to use multi-value returns.

Generates dart bindings for the rust api.

Generates js bindings for the rust api.

Generates typescript type definitions for the js bindings.